3.7.2. pypago.areadiag — PyPAGO 1.0.1 documentation

# 3.7.2. pypago.areadiag

Module that handles domain calculation into domains

Functions

`compute_tracer_conv`(area, sections, componame) | Calculation of tracer convergence within the domain:
`compute_tracer_conv_trans`(area, sections, …) | Calculation of tracer convergence within the domain:
`surface_content`(area, componame) | Computation of surface integrated tracer content.
`volume_content`(area, componame) | Computation of volume integrated tracer content:

`pypago.areadiag.` `compute_tracer_conv`(area, sections, componame, velname='vecv')

  Calculation of tracer convergence within the domain:

  > \[\sum_{i=1}^N\left[\iint_{S_{i}} [U T]\ dl\ dz\right]\]

  > with i the section index.

  Parameters: | area (pypago.area.Area) – Closed domain sections (list) – List of pypago.sections.GridSection objects, containing the sections that define the domain componame (str) – Name of the tracer variable velname (str) – Name of the velocity field
  Returns: | A numpy array containing the tracer convergence.

`pypago.areadiag.` `compute_tracer_conv_trans`(area, sections, velname)

  Calculation of tracer convergence within the domain:

  > \[\sum_{i=1}^N\left[\iint_{S_{i}} [U T]\ dl\ dz\right]\]

  > with i the section index.

  > In this function, the `velname` argument is already a transport.

  > Note

  > Use this function if the heat transport has been stored by the model, since it provides a better precision than offline calculation

  Parameters: | area (pypago.area.Area) – Closed domain sections (list) – List of pypago.sections.GridSection objects, containing the sections that define the domain velname (str) – Name of the transport field.
  Returns: | A numpy array containing the tracer convergence.

`pypago.areadiag.` `surface_content`(area, componame)

  Computation of surface integrated tracer content.

  - If the tracer field is 2D (time, space)
  \[HC = \iint_S T dS\]
  - If the tracer field is 3D (time, space)
  \[HC = \iint_S T(k=0) dS\]

`pypago.areadiag.` `volume_content`(area, componame)

  Computation of volume integrated tracer content:

  \[HC = \iiint_V T dV\]